//
//  ContentView.swift
//  SwiftUIChanges
//
//  Created by Mohammad Azam on 6/8/23.
//

import SwiftUI
import SwiftData

@Observable
class Light {
    var isOn: Bool = false
}

struct LightView: View {
    
    @Bindable var light: Light
    
    var body: some View {
           Toggle(isOn: $light.isOn) {
               EmptyView()
           }.fixedSize()
       }
}

struct Room: View {
    
    @Environment(Light.self) private var light
    
    var body: some View {
       LightView(light: light)
    }
    
}

struct Cabin: View {
    
    @Environment(Light.self) private var light
    
    var body: some View {
        Image(systemName: light.isOn ? "lightbulb.fill": "lightbulb")
            .font(.largeTitle)
    }
}

struct ContentView: View {
    
    @Environment(Light.self) private var light
    
    var body: some View {
        VStack {
            Room()
            Cabin()
        }
        .frame(maxWidth: .infinity, maxHeight: .infinity)
        .background(light.isOn ? .yellow: .white)
    }
}

#Preview {
    ContentView()
        .environment(Light())
}
